@@ -1,6 +1,5 @@
 #!/usr/bin/env bash
-
 GO111MODULE=on ${GOPATH}/bin/golangci-lint run \
     --tests=false --enable gofmt \
-    --timeout=10m0s \
+    --timeout=15m0s --verbose --print-resources-usage --modules-download-mode=vendor \
     && echo "lint OK!"
