@@ -1,10 +1,13 @@
 package main
 
 import (
+	"context"
 	"fmt"
 	"os"
+	"os/signal"
+	"syscall"
 
-	"github.com/urfave/cli"
+	"github.com/urfave/cli/v2"
 
 	"github.com/ovn-org/ovn-kubernetes/go-controller/hybrid-overlay/pkg/controller"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/config"
@@ -24,7 +27,7 @@ func main() {
 	c.Usage = "a node controller to integrate disparate networks with VXLAN tunnels"
 	c.Version = config.Version
 	c.Flags = config.GetFlags([]cli.Flag{
-		cli.StringFlag{
+		&cli.StringFlag{
 			Name:        "node",
 			Usage:       "The name of this node in the Kubernetes cluster.",
 			Destination: &nodeName,
@@ -36,8 +39,32 @@ func main() {
 		return nil
 	}
 
-	if err := c.Run(os.Args); err != nil {
-		klog.Fatal(err)
+	ctx := context.Background()
+
+	// trap SIGHUP, SIGINT, SIGTERM, SIGQUIT and
+	// cancel the context
+	ctx, cancel := context.WithCancel(ctx)
+	exitCh := make(chan os.Signal, 1)
+	signal.Notify(exitCh,
+		syscall.SIGHUP,
+		syscall.SIGINT,
+		syscall.SIGTERM,
+		syscall.SIGQUIT)
+	defer func() {
+		signal.Stop(exitCh)
+		cancel()
+	}()
+	go func() {
+		select {
+		case s := <-exitCh:
+			klog.Infof("Received signal %s. Shutting down", s)
+			cancel()
+		case <-ctx.Done():
+		}
+	}()
+
+	if err := c.RunContext(ctx, os.Args); err != nil {
+		klog.Exit(err)
 	}
 }
 
@@ -60,19 +87,20 @@ func runHybridOverlay(ctx *cli.Context) error {
 		return err
 	}
 
-	stopChan := make(chan struct{})
-	defer close(stopChan)
-
-	factory, err := factory.NewWatchFactory(clientset, stopChan)
+	factory, err := factory.NewWatchFactory(clientset)
 	if err != nil {
 		return err
 	}
 
+	stopChan := make(chan struct{})
 	kube := &kube.Kube{KClient: clientset}
 	if err := controller.StartNode(nodeName, kube, factory, stopChan); err != nil {
 		return err
 	}
 
-	// run forever
-	select {}
+	// run until cancelled
+	<-ctx.Context.Done()
+	close(stopChan)
+	factory.Shutdown()
+	return nil
 }
