@@ -6,6 +6,7 @@ import (
 	"github.com/containernetworking/cni/pkg/types/current"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/cni/types"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/util"
+	"k8s.io/client-go/kubernetes"
 )
 
 // serverRunDir is the default directory for CNIServer runtime files
@@ -69,7 +70,7 @@ type PodRequest struct {
 	CNIConf *types.NetConf
 }
 
-type cniRequestFunc func(request *PodRequest) ([]byte, error)
+type cniRequestFunc func(request *PodRequest, kclient kubernetes.Interface) ([]byte, error)
 
 // Server object that listens for JSON-marshaled Request objects
 // on a private root-only Unix domain socket.
@@ -77,4 +78,5 @@ type Server struct {
 	http.Server
 	requestFunc cniRequestFunc
 	rundir      string
+	kclient     kubernetes.Interface
 }
