@@ -2,8 +2,10 @@ package ovn
 
 import (
 	"fmt"
+	"net"
 	"time"
 
+	hotypes "github.com/ovn-org/ovn-kubernetes/go-controller/hybrid-overlay/pkg/types"
 	kapi "k8s.io/api/core/v1"
 	utilwait "k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/klog"
@@ -151,6 +153,25 @@ func (oc *Controller) AddNamespace(ns *kapi.Namespace) {
 		}
 	}
 
+	annotation := ns.Annotations[hotypes.HybridOverlayExternalGw]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay external gw annotation")
+		} else {
+			nsInfo.hybridOverlayExternalGW = parsedAnnotation
+		}
+	}
+	annotation = ns.Annotations[hotypes.HybridOverlayVTEP]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay VTEP annotation")
+		} else {
+			nsInfo.hybridOverlayVTEP = parsedAnnotation
+		}
+	}
+
 	// Create an address_set for the namespace.  All the pods' IP address
 	// in the namespace will be added to the address_set
 	createAddressSet(ns.Name, hashedAddressSet(ns.Name), addresses)
@@ -168,6 +189,24 @@ func (oc *Controller) updateNamespace(old, newer *kapi.Namespace) {
 	}
 	defer nsInfo.Unlock()
 
+	annotation := newer.Annotations[hotypes.HybridOverlayExternalGw]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay external gw annotation")
+		} else {
+			nsInfo.hybridOverlayExternalGW = parsedAnnotation
+		}
+	}
+	annotation = newer.Annotations[hotypes.HybridOverlayVTEP]
+	if annotation != "" {
+		parsedAnnotation := net.ParseIP(annotation)
+		if parsedAnnotation == nil {
+			klog.Errorf("Could not parse hybrid overlay VTEP annotation")
+		} else {
+			nsInfo.hybridOverlayVTEP = parsedAnnotation
+		}
+	}
 	oc.multicastUpdateNamespace(newer, nsInfo)
 }
 
