@@ -152,7 +152,7 @@ func waitForPodAddresses(portName string) (net.HardwareAddr, net.IP, error) {
 	return podMac, podIP, nil
 }
 
-func getRoutesGatewayIP(pod *kapi.Pod, gatewayIPnet *net.IPNet) ([]util.PodRoute, net.IP, error) {
+func getRoutesGatewayIP(pod *kapi.Pod, subnet *net.IPNet, hybridOverlayExternalGW net.IP) ([]util.PodRoute, net.IP, error) {
 	// if there are other network attachments for the pod, then check if those network-attachment's
 	// annotation has default-route key. If present, then we need to skip adding default route for
 	// OVN interface
@@ -168,9 +168,10 @@ func getRoutesGatewayIP(pod *kapi.Pod, gatewayIPnet *net.IPNet) ([]util.PodRoute
 			break
 		}
 	}
+	gatewayIPnet := util.GetNodeGatewayIfAddr(subnet)
 	var gatewayIP net.IP
 	routes := make([]util.PodRoute, 0)
-	if otherDefaultRoute {
+	if otherDefaultRoute || len(hybridOverlayExternalGW) > 0 {
 		for _, clusterSubnet := range config.Default.ClusterSubnets {
 			var route util.PodRoute
 			route.Dest = clusterSubnet.CIDR
@@ -183,6 +184,9 @@ func getRoutesGatewayIP(pod *kapi.Pod, gatewayIPnet *net.IPNet) ([]util.PodRoute
 			route.NextHop = gatewayIPnet.IP
 			routes = append(routes, route)
 		}
+		if len(hybridOverlayExternalGW) > 0 {
+			gatewayIP = util.GetNodeHybridOverlayIfAddr(subnet).IP
+		}
 	} else {
 		gatewayIP = gatewayIPnet.IP
 	}
@@ -199,10 +203,18 @@ func getRoutesGatewayIP(pod *kapi.Pod, gatewayIPnet *net.IPNet) ([]util.PodRoute
 			})
 		}
 	}
-
 	return routes, gatewayIP, nil
 }
 
+func (oc *Controller) getHybridOverlayExternalGwAnnotation(ns string) (net.IP, error) {
+	nsInfo, err := oc.waitForNamespaceLocked(ns)
+	if err != nil {
+		return nil, err
+	}
+	defer nsInfo.Unlock()
+	return nsInfo.hybridOverlayExternalGW, nil
+}
+
 func (oc *Controller) addLogicalPort(pod *kapi.Pod) error {
 	var out, stderr string
 	var err error
@@ -326,15 +338,27 @@ func (oc *Controller) addLogicalPort(pod *kapi.Pod) error {
 	}
 
 	if annotation == nil {
-		gwIfAddr := util.GetNodeGatewayIfAddr(nodeSubnet)
-		routes, gwIP, err := getRoutesGatewayIP(pod, gwIfAddr)
+		hybridOverlayExternalGW := net.IP{}
+		if config.HybridOverlay.Enabled {
+			hybridOverlayExternalGW, err = oc.getHybridOverlayExternalGwAnnotation(pod.Namespace)
+			if err != nil {
+				return err
+			}
+		}
+		routes, gwIP, err := getRoutesGatewayIP(pod, nodeSubnet, hybridOverlayExternalGW)
 		if err != nil {
 			return err
 		}
+
+		var gwIPs []net.IP
+		if gwIP != nil {
+			gwIPs = []net.IP{gwIP}
+		}
+
 		marshalledAnnotation, err := util.MarshalPodAnnotation(&util.PodAnnotation{
 			IPs:      []*net.IPNet{podCIDR},
 			MAC:      podMac,
-			Gateways: []net.IP{gwIP},
+			Gateways: gwIPs,
 			Routes:   routes,
 		})
 		if err != nil {
@@ -342,7 +366,7 @@ func (oc *Controller) addLogicalPort(pod *kapi.Pod) error {
 		}
 
 		klog.V(5).Infof("Annotation values: ip=%s ; mac=%s ; gw=%s\nAnnotation=%s",
-			podCIDR, podMac, gwIP, marshalledAnnotation)
+			podCIDR, podMac, gwIPs, marshalledAnnotation)
 		if err = oc.kube.SetAnnotationsOnPod(pod, marshalledAnnotation); err != nil {
 			return fmt.Errorf("failed to set annotation on pod %s: %v", pod.Name, err)
 		}
